[<img align="right" alt="Grid Smarter Cities" src="https://s3.eu-west-2.amazonaws.com/open-source-resources/grid_smarter_cities_small.png">](https://www.gridsmartercities.com/)

![Build Status](https://codebuild.eu-west-2.amazonaws.com/badges?uuid=eyJlbmNyeXB0ZWREYXRhIjoiTlhUdENsZkFTZzhmejdiWk5Ya1hzd1JqUk1wdjBjU015aktYTnJnM0taSXJxYXFCNnQ4RmZ4Ym5CUUlnOVYwbUtoRnM2djhuQ0s5bUgrUDRPVE1zRmZ3PSIsIml2UGFyYW1ldGVyU3BlYyI6ImIyZ2Fpd3J5d01SS2kzU1giLCJtYXRlcmlhbFNldFNlcmlhbCI6MX0%3D&branch=master)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
![Github Release](https://img.shields.io/github/release/gridsmartercities/aws-v4signer.svg?style=flat)
\
\
![Python Versions](https://img.shields.io/pypi/pyversions/aws-v4signer.svg?style=flat)
![PyPi Version](https://img.shields.io/pypi/v/aws-v4signer.svg?style=flat)
![PyPi Status](https://img.shields.io/pypi/status/aws-v4signer.svg?style=flat)
![Pypi Downloads](https://img.shields.io/pypi/dm/aws-v4signer.svg?style=flat&logo=pypi)

# aws-python-v4signer

A python package to obtain AWS v4 signature headers.

 



